@@ -7,5 +7,5 @@ log.disabled = True
 
 
 def run():
-    for x in range(500):
+    for _ in range(500):
         log.warning("this is not handled")
