@@ -11,5 +11,5 @@ log.level = ERROR
 def run():
     out = StringIO()
     with StreamHandler(out):
-        for x in range(500):
+        for _ in range(500):
             log.warning("this is not handled")
